@@ -4,26 +4,26 @@
 # pylint: disable=line-too-long
 
 import datetime
-import glob
 import os
+import pdb
 import re
 import shelve
 import shutil
 import statistics
+import sys
 from pathlib import Path
 
 import appdirs
 import rich
 import rich.traceback
 import toml
+import typer
 
-from .parser.clean_parser import clean_parser
+main_app = typer.Typer()
 
-clean_parser.prog = "py -m rob." + Path(__file__).stem
+archive_app = typer.Typer()
+main_app.add_typer(archive_app, name="archive", help="Clean an existing archive.")
 
-_ARGS = clean_parser.parse_args()
-
-_CLI_PATH = Path(_ARGS.path)
 
 _THIS_FILE = Path(__file__)
 
@@ -51,8 +51,8 @@ with open(_BASE_CONFIG_FILE, "r") as fp:
 if _USER_CONFIG_FILE.exists():
     with (open(_USER_CONFIG_FILE, "r")) as fp:
         USER_SETTINGS = toml.load(fp)
+        _SETTINGS.update(USER_SETTINGS)
 
-_SETTINGS.update(USER_SETTINGS)
 
 # _CROWDED_FOLDER = _SETTINGS["CROWDED_FOLDER"]  # number of files that is 'crowded'
 _FILE_TYPES: dict[str, list[str]] = _SETTINGS[
@@ -82,7 +82,8 @@ _EXTENSION_HANDLER = generate_extension_handler(_FILE_TYPES)
 def isolate_crowded_folders(
     folders: list[Path], crowded_threshold: int = 20
 ) -> list[Path]:
-    """Return a list of directories with many files inside."""
+    """Return a list of directories with many files inside.
+    post: True"""
 
     crowded = []
 
@@ -155,12 +156,19 @@ def approve_list(target: list, desc: str = "", repr_func=None) -> list:
     return approved_targets
 
 
-def approve_dict(target: dict, desc: str = "") -> dict:
+def approve_dict(target: dict, desc: str = "", repr_func=None) -> dict:
     """Returns a user-approved subset of target dictionary."""
 
     if not target:
         return {}
 
+    if not repr_func:
+        source_chars = max(len(str(key)) for key in target.keys())
+        dest_chars = max(len(str(target[key])) for key in target.keys())
+        repr_func = (
+            lambda key: f"{str(key):<{source_chars}} -> {str(target[key]):>{dest_chars}}"
+        )
+
     approved_keys = []
     frozen_keys = list(target.keys())
     final_choice = False
@@ -169,9 +177,11 @@ def approve_dict(target: dict, desc: str = "") -> dict:
         rich.print(desc, end="\n\n")
         for count, key in enumerate(frozen_keys):
             if key in approved_keys:
-                rich.print(f" [green]{count+1}.) {key}[yellow]->[green]{target[key]}")
+                # rich.print(f" [green]{count+1:2}.) {key}[yellow]->[green]{target[key]}")
+                rich.print(f" [green]{count+1:2}.){repr_func(key)}")
             else:
-                rich.print(f" [red]{count+1}.) {key}[yellow]->[red]{target[key]}")
+                # rich.print(f" [red]{count+1}.) {key}[yellow]->[red]{target[key]}")
+                rich.print(f" [red]{count+1:2}.){repr_func(key)}")
 
         style = _PROMPT_STYLE if not invalid else _ERROR_STYLE
         rich.print(
@@ -304,7 +314,7 @@ def handle_files(
     files: list[str],
     folder: str = "misc",
     month: bool = False,
-    yes_all: bool = _ARGS.yes,
+    yes_all: bool = True,
 ) -> None:
     """Organizes files by last modified date."""
     choice = ""
@@ -358,74 +368,65 @@ def remove_empty_dir(path: str | Path):
         os.rmdir(path)
         print(f"Removing empty folder ({path}).")
     except OSError as e:
-        if _ARGS.debug:
-            print(f"Could not remove folder: {e}")
-        else:
-            pass
+        pass
 
 
-def remove_empty_dirs(path: str | Path):
+@archive_app.command(name="empty")
+def remove_empty_dirs(target: Path = Path(".")):
     """Recursively remove empty folders."""
 
-    for trunk, dirnames, _ in os.walk(path, topdown=False):
+    for trunk, dirnames, _ in os.walk(target, topdown=False):
         for dirname in dirnames:
             remove_empty_dir(os.path.realpath(os.path.join(trunk, dirname)))
 
-    remove_empty_dir(path)
+    remove_empty_dir(target)
 
 
-def clean_up() -> None:
-    for target_folder in ARCHIVE_FOLDERS:
-        remove_empty_dirs(os.path.join(_CLI_PATH, target_folder))
+@main_app.command()
+def undo(target: Path = Path("."), yes_all=False) -> None:
+    """Undo file manipulations in target directory."""
 
-
-def undo() -> None:
     undo_commands = {}
     breakpoint()
     with shelve.open(str(_UNDO_FILE)) as db:
         try:
-            old_commands = db[str(_CLI_PATH.absolute())]
+            old_commands = db[str(target.absolute())]
             for source, dest in old_commands.items():
-                undo_commands[dest] = _CLI_PATH.absolute() / source
+                undo_commands[dest] = target.absolute() / source
                 # undo_commands.append((command, dest, source))
                 # _COMMANDS.append((command, dest, source))
 
         except KeyError:
             rich.print(
-                f"[red]No recorded commands executed on ({Path(_CLI_PATH).absolute()})."
+                f"[red]No recorded commands executed on ({Path(target).absolute()})."
             )
             exit(1)
 
     preview_mvs(undo_commands)
 
-    # rich.print("[red]Execute:")
-    # skipped = []
-    # for command, source, dest in undo_commands:
-    #     if source.exists():
-    #         rich.print(f"[yellow]mv '{source}' '{dest}'")
-    #     else:
-    #         rich.print(f"[red]mv '{source}' '{dest}' (ERROR 404)")
-    #         skipped.append((command, source, dest))
+    breakpoint()
+    if yes_all:
+        choice = "y"
+    else:
+        rich.print("[red]Are you sure? (y/n)")
+        choice = input(f"{_PROMPT}")
 
-    # for skip in skipped:
-    #     undo_commands.remove(skip)
-
-    rich.print("[red]Are you sure? (y/n)")
-    choice = input(f"{_PROMPT}") if not _ARGS.yes else "y"
     if choice in ["y", "yes", "Y", "YES"]:
         try:
             execute_move_commands(undo_commands)
 
         except Exception as e:
             with shelve.open(str(_UNDO_FILE)) as db:
-                del db[str(_CLI_PATH.absolute())]
+                del db[str(target.absolute())]
             print(e)
             exit(1)
         with shelve.open(str(_UNDO_FILE)) as db:
-            db[str(_CLI_PATH.absolute())] = undo_commands
+            db[str(target.absolute())] = undo_commands
 
             # pickle.dump(_COMMANDS, _UNDO_FILE)
 
+    remove_empty_dirs(target)
+
 
 #  ^^^^^^^^^^^^^^^^^^^^^^^^^^
 #  </ def undo()>
@@ -433,34 +434,37 @@ def undo() -> None:
 
 
 def preview_mvs(renames: dict[Path, Path]):
-    """Print a list of mv targets."""
+    """Print a list of mv targets.
+    post: True"""
     for source, dest in renames.items():
         rich.print(f"mv [green]{source.name} [red]{dest.absolute()}")
 
 
-def execute_move_commands(commands: dict[Path, Path]):
+def execute_move_commands(commands: dict[Path, Path], target: Path = Path(".")):
     """Execute a sequence of file move commands.
 
     Args:
         commands: A dictionary with source keys and destination values.
+    post: True
     """
     sources = list(commands.keys())
     for source in sources:
         try:
             os.makedirs(commands[source].parent.absolute(), exist_ok=True)
             shutil.move(source.absolute(), commands[source].absolute())
-            # os.rename(source.absolute(), commands[source].absolute())
 
         # File of Same Name Has Already Been Moved To Folder
         except shutil.Error as e:
             print(e)
-
+        except FileNotFoundError as e:
+            rich.print(f"{_ERROR_STYLE}{source.absolute()} not found.")
     with shelve.open(str(_UNDO_FILE)) as db:
-        db[str(_CLI_PATH.absolute())] = commands
+        db[str(target.absolute())] = commands
 
 
 def create_config():
-    """Create a config file in users app data directory that overrides base settings."""
+    """Create a config file in users app data directory that overrides base settings.
+    post: True"""
 
     os.makedirs(_USER_CONFIG_FILE.parent, exist_ok=True)
     shutil.copyfile(_BASE_CONFIG_FILE, _USER_CONFIG_FILE)
@@ -501,16 +505,16 @@ def gather_files(
     return []
 
 
+@main_app.command(name="files")
 def clean_files(
     target: Path = Path("."),
     recurse: bool = False,
     yes_all: bool = False,
-    extension_handler: dict[str, str] | None = None,
+    # extension_handler: dict[str, str] | None = None,
     exclusions: list[Path] | None = None,
 ) -> None:
-    """Clean the files in target root directory using an extension handler that associates extensions to folders.
-    post: True"""
-
+    """Clean the files by extension in target root directory."""
+    extension_handler = _EXTENSION_HANDLER
     if recurse:
         root_files = target.rglob("*.*")
     else:
@@ -533,9 +537,10 @@ def clean_files(
 
     if approved_mvs:
         preview_mvs(approved_mvs)
-        execute_move_commands(approved_mvs)
+        execute_move_commands(approved_mvs, target=target)
 
 
+@archive_app.command(name="large")
 def identify_large_files(target: Path = Path("."), yes_all: bool = False) -> None:
     """Find large files in target directory and offer to centralize them."""
 
@@ -544,13 +549,18 @@ def identify_large_files(target: Path = Path("."), yes_all: bool = False) -> Non
     ]
     sub_folders = []
     all_files = []
+
     for folder in archive_folders:
-        sub_folders.extend(list(folder.glob(f"{folder} [0-9][0-9][0-9][0-9]/")))
+        sub_folders.extend(list(folder.glob(f"{folder.name} [0-9][0-9][0-9][0-9]/")))
 
     for sub_folder in sub_folders:
         all_files.extend(sub_folder.rglob("*.*"))
 
     # all_files = gather_files(target=target, recurse=True, recursion_limit=3)
+    if not all_files:
+        rich.print("No archives found.")
+        return
+
     file_sizes = [os.stat(file.absolute()).st_size for file in all_files]
     avg_file_size = sum(file_sizes) / len(file_sizes)
     standard_deviation = statistics.stdev(file_sizes)
@@ -602,10 +612,17 @@ def identify_large_files(target: Path = Path("."), yes_all: bool = False) -> Non
         execute_move_commands(large_mvs)
 
 
+@archive_app.command(name="crowded")
 def identify_crowded_archives(
-    target: Path = Path("."), threshold: int = 20, yes_all: bool = False
+    target: Path = typer.Option(default=Path("."), help="target path"),
+    threshold: int = typer.Option(
+        default=20, help="number of files to qualify as crowded"
+    ),
+    yes_all: bool = typer.Option(
+        default=False, help="always apply all routines to all valid files"
+    ),
 ) -> None:
-    """Identify crowded folders and offer to uncrowd them."""
+    """Archives with file count exceeding threshold is sub-divided by month folders."""
 
     archive_folders = [Path(f"{key}") for key in _FILE_TYPES.keys()]
     all_folders = []
@@ -640,48 +657,23 @@ def identify_crowded_archives(
         execute_move_commands(uncrowded_mvs)
 
 
-def main():
-    # rich.traceback.install()
-
-    # if not os.path.isdir(_CLI_PATH):
-    if not _CLI_PATH.exists():
-        rich.print(f"[red on black]The specified path ({_CLI_PATH}) does not exist.")
-        exit(1)
-
-    if _ARGS.undo:
-        undo()
-        clean_up()
-        exit(0)
-
-    if _ARGS.config:
-        create_config()
-        exit(0)
-
-    if _ARGS.debug:
-        breakpoint()
-
-    clean_files(
-        target=_CLI_PATH,
-        recurse=_ARGS.recurse,
-        yes_all=_ARGS.yes,
-        extension_handler=_EXTENSION_HANDLER,
-        exclusions=_EXCLUSIONS,
-    )
-
-    identify_large_files(target=_CLI_PATH, yes_all=_ARGS.yes)
-
+@main_app.command()
+def all(target: Path = Path("."), recurse: bool = False, yes_all: bool = False):
+    """Apply all available cleaning routines."""
+    clean_files(target=target, recurse=recurse, exclusions=_EXCLUSIONS, yes_all=yes_all)
+    identify_large_files(target=target, yes_all=yes_all)
     identify_crowded_archives(
-        target=_CLI_PATH, threshold=_SETTINGS["CROWDED_FOLDER"], yes_all=_ARGS.yes
+        target=target, threshold=_SETTINGS["CROWDED_FOLDER"], yes_all=yes_all
     )
-
-    clean_up()
+    remove_empty_dirs(target=target)
 
     return
 
 
-#  ^^^^^^^^^^^^^^^^^^^^^^^^^^
-#  </ def main()>
-#  ^^^^^^^^^^^^^^^^^^^^^^^^^^
-
 if __name__ == "__main__":
-    main()
+    if len(sys.argv) == 1:
+        all()
+        exit(0)
+
+    main_app()
+    # main()
