@@ -1,9 +1,9 @@
 import glob
-
+import sys
 from pathlib import Path
 
-import toml, rich, sys
-
+import rich
+import toml
 
 _EXCLUSIONS = ["__init__", "__main__"]
 
@@ -19,7 +19,6 @@ def main():
     )
 
     scripts = []
-    # breakpoint()
     for elem in glob.glob(f"{Path(__file__).parent}/*.py"):
         if Path(elem).stem not in _EXCLUSIONS:
             scripts.append("rob." + Path(elem).stem)
