@@ -1,22 +1,24 @@
-import os
 import datetime
-import time
-import subprocess
-
-from pathlib import Path
-
-import appdirs
-
-
-# Register App with ticktick servers at https://developer.ticktick.com/manage
-from .ticktick.oauth2 import OAuth2
-from .ticktick.api import TickTickClient
 
 # for debugging the daemon
 import logging
-from .loggers.tick_logger import StreamToLogger
+import os
+import random
+import subprocess
+import sys
+import time
+from pathlib import Path
 
-from .parser.tick_parser import tick_parser
+import appdirs  # type: ignore[import]
+
+from .loggers.tick_logger import StreamToLogger, log
+from .parser.tick_parser import tick_parser  # type: ignore[import]
+from .ticktick.api import TickTickClient
+
+# Register App with ticktick servers at https://developer.ticktick.com/manage
+from .ticktick.oauth2 import OAuth2
+
+_DEBUG = True
 
 tick_parser.prog = "py -m rob." + Path(__file__).stem
 
@@ -44,7 +46,6 @@ if not _TICKTICK_USERNAME or not _TICKTICK_USERNAME:
     )
     exit(1)
 
-
 _TOKEN_FILE = _BASE_PATH / "robolson" / "tick" / "cache" / ".token-oauth"
 
 if not _TOKEN_FILE.exists():
@@ -52,7 +53,6 @@ if not _TOKEN_FILE.exists():
 
 if args.token:
     os.remove(_TOKEN_FILE)
-
 _TASK_FILE = os.environ.get("TICKTICK_TASK_FILE", "")
 if not _TASK_FILE:
     _TASK_FILE = _BASE_PATH / "robolson" / "tick" / "tasks.txt"
@@ -71,11 +71,11 @@ if args.get:
 
 
 def get_due(tick_client) -> list[str]:
-    today = datetime.datetime.today().isoformat("!")
-    today_date = today
-    today = today.split("!")[0]
+    today_str = datetime.datetime.today().isoformat("!")
+    today_date = today_str
+    today_str = today_str.split("!")[0]
 
-    today = datetime.datetime.fromisoformat(today)
+    today = datetime.datetime.fromisoformat(today_str)
 
     due = [
         elem
@@ -90,14 +90,18 @@ def get_due(tick_client) -> list[str]:
 
 def main() -> None:
 
-    # For Debugging, these will redirect standard streams to the logger
-    # stdout_logger = logging.getLogger("STDOUT")
-    # sl = StreamToLogger(stdout_logger, logging.INFO)
-    # sys.stdout = sl
+    breakpoint()
 
-    # stderr_logger = logging.getLogger("STDERR")
-    # sl = StreamToLogger(stderr_logger, logging.ERROR)
-    # sys.stderr = sl
+    global args
+    if _DEBUG:
+        # For Debugging, these will redirect standard streams to the logger
+        stdout_logger = logging.getLogger("STDOUT")
+        sl = StreamToLogger(stdout_logger, logging.INFO)
+        sys.stdout = sl
+
+        stderr_logger = logging.getLogger("STDERR")
+        sl = StreamToLogger(stderr_logger, logging.ERROR)
+        sys.stderr = sl
 
     auth_client = OAuth2(
         client_id=_CLIENT_ID,
@@ -116,7 +120,7 @@ def main() -> None:
 
         with open(f"{_TASK_FILE}", "w") as fp:
             if due:
-                fp.write("\n".join([elem["title"] for elem in due]))
+                fp.write("\n".join([elem["title"] for elem in due]))  # type: ignore[index]
             else:
                 fp.write("")
 
@@ -129,15 +133,56 @@ def main() -> None:
     while True:
         due = get_due(tick_client)
 
+        # Create Overdue Tasks in "me" list for Pavlok
+        for task in due:
+            # Do not trigger during sleeping hours
+            if not 8 < datetime.datetime.now().hour < 20:
+                continue
+
+            due_date = datetime.datetime.fromisoformat(task["dueDate"][:-5])
+            due_diff = datetime.datetime.now() - due_date
+
+            if due_diff.days > 0 and 0.99**due_diff.days < random.random():
+
+                if task["projectId"] == "54384b29b84562b41688e91a":
+                    # If task in Joes List, add to Joes Pavlok List
+                    new_projectId = "8999486ebf8fc984f752dd46"
+
+                elif task["projectId"] == "af22459697ae1243ca23f4d9":
+                    # If task in Eryns List, add to Eryns Pavlok List
+                    new_projectId = "88ba4b50ab907613d84d0cb6"
+
+                else:
+                    # Add to Robs Pavlok List
+                    new_projectId = "611479cafba2c1d019f96b45"
+
+                new_due = datetime.datetime.fromordinal(
+                    datetime.datetime.today().toordinal()
+                )
+                new_due = new_due + datetime.timedelta(hours=20)
+                new_due = new_due.isoformat("T") + "+0000"
+                new_task = tick_client.task.builder(
+                    title=f"Overdue({due_diff.days}): {task['title']}",
+                    dueDate=new_due,
+                    content="Created for Pavlok",
+                    priority=5,
+                    projectId=new_projectId,
+                )
+                new_task["dueDate"] = new_due
+                tick_client.task.create(new_task)
+
         with open(f"{_TASK_FILE}", "w") as fp:
             if due:
-                fp.write("\n".join([elem["title"] for elem in due]))
+                # write name of due task to file if it is assigned to inbox
+                fp.write("\n".join([elem["title"] for elem in due if elem["projectId"] == "inbox115493726"]))  # type: ignore[index]
             else:
                 fp.write("")
 
-        time.sleep(299)
+        # log.info("syncing with ticktick servers")
         tick_client.sync()
 
+        time.sleep(299)
+
 
 if __name__ == "__main__":
     main()
