@@ -1,5 +1,7 @@
+import deal
 class FocusTimeManager:
 
+    @deal.pure
     def __init__(self, client_class):
         self._client = client_class
         self.access_token = ''
@@ -7,6 +9,7 @@ class FocusTimeManager:
     #   ---------------------------------------------------------------------------------------------------------------
     #   Focus Timer Methods
 
+    @deal.pure
     def start(self):
         """Starts the focus timer"""
         pass
